/**
 * Retrieves the translation of text.
 *
 * @see https://developer.wordpress.org/block-editor/reference-guides/packages/packages-i18n/
 */
import { __ } from "@wordpress/i18n";

import { TextControl } from "@wordpress/components";

/**
 * React hook that is used to mark the block wrapper element.
 * It provides all the necessary props like the class name.
 *
 * @see https://developer.wordpress.org/block-editor/reference-guides/packages/packages-block-editor/#useblockprops
 */
import { useBlockProps } from "@wordpress/block-editor";

/**
 * Lets webpack process CSS, SASS or SCSS files referenced in JavaScript files.
 * Those files can contain any CSS code that gets applied to the editor.
 *
 * @see https://www.npmjs.com/package/@wordpress/scripts#using-css
 */
import "./editor.scss";

/**
 * The edit function describes the structure of your block in the context of the
 * editor. This represents what the editor will render when the block is used.
 *
 * @see https://developer.wordpress.org/block-editor/reference-guides/block-api/block-edit-save/#edit
 *
 * @return {WPElement} Element to render.
 */
export default function Edit({ attributes, setAttributes }) {
	return (
		<div {...useBlockProps()}>
			<div className="editor-inner">
				<TextControl
					label="Title"
					value={attributes.title}
					onChange={(val) => setAttributes({ title: val })}
				/>
				<TextControl
					label="href"
					value={attributes.href}
					onChange={(val) => setAttributes({ href: val })}
				/>
				<TextControl
					label="body"
					value={attributes.body}
					onChange={(val) => setAttributes({ body: val })}
				/>
				{/* <h2>{attributes.title}</h2>
				{attributes.body && <p>{attributes.body}</p>} */}
			</div>
		</div>
	);
}
